#install.packages('lmtest') 
#install.packages('spgs')
#install.packages('lattice')
#install.packages('ggplot2')
#install.packages("viridis")
#install.packages('parallelMap')
#install.packages('randtests') 
#install.packages('evd')
#install.packages('data.table')
#install.packages('nimble')
#install.packages('fGarch')
#install.packages('sarima')
#install.packages('forecast')
#install.packages('tsDyn')
#install.packages('synlik')
#install.packages('latex2exp')
#install.packages('rasterVis')
install.packages('gridExtra')
install.packages('pastecs')
install.packages('bigmemory')
install.packages('rlist')




library(tseries) #Runs-Test + #BDS-test
library(lmtest)  #Durbin-Watson + #Breusch Godfrey
library(devtools)
library(spgs) # Turning-Point-Test
library(randtests) #Difference-Runs-Test # VNR
library(GSignTest) #Vorzeichentiefe
library(lattice) #heatmap
library(viridis) # Farbpalette
library(parallelMap) # Parallelisierung am Heimrechner
library(evd) # gumbel verteilung
library(data.table) # Karthesisches Produkt
library(nimble) # Doppelexponentialverteilung
library(fGarch) # Garch-Simulationen
library(sarima) # saisonale arima-Modelle
library(forecast) #  auto-Arima-Funktion
library(tsDyn)
library(synlik)
library(latex2exp)
library(magicaxis)
library(gridExtra)
library(pastecs)
library(bigmemory)
#library(latticeExtra)
#library(rasterVis)
library(rlist)



######### loading depth tests

devtools::install_github("melaniehorn/GSignTest")


######### Setting seed

set.seed(123)


#________________________________________________________________________________________________________
############################################## Functions ###############################################
#________________________________________________________________________________________________________


### Signs

sign_w0 <- function(x){                        
  x <- sign(x)
  if(length(which(x == 0)) > 0){
    x <- x[-which(x == 0)]}
  return(x)
}



####### Tests Simplified

TestsSimp<- function(order=order,QK=QK,rho=rho,mean=mean,center=center,n=n,distr=distr,df=df,scale=scale,shockno=shockno,shockint=shockint, shocktime=shocktime, kontno=kontno, kontint=kontint, konttime=konttime){
  
  #Generieren + Residuen +Signs
  if ((distr=='norm')){
    shock=rnorm(n)
  }  else
  {if (!(is.null(df))){
    shock=do.call(paste("r",distr[[1]],sep=""),args=list(n=n, df=df))
  } else
  {if (!(missing(scale))){
    shock=do.call(paste("r",distr[[1]],sep=""),args=list(n=n, scale=scale))}
  }}
  
  shock[shocktime]= sample(c(-1,1),shockno,replace=T)*shockint
  sim_data=arima.sim(list(order=order, ar=rho,mean=mean),innov=shock, n=n)
  sim_data[konttime]= sim_data[konttime]+sample(c(-1,1),kontno,replace=T)*kontint
  res_sim = sim_data - median(sim_data)
  sign_sim= sign_w0(res_sim)
  
  #Tests
  dw= dwtest(sim_data~ 1+seq(1,n), alternative= 'two.sided')$p
  bg=bgtest(sim_data~1 + seq(1,n))$p.value
  lb=Box.test(sim_data, lag = 15, type = "Ljung-Box", fitdf = 0)$p.value
  bds=bds.test(sim_data,m=2, eps= 0.5*sd(sim_data))$p.value                 #S. BDS-Statistic 2.
  runs=tseries::runs.test(as.factor(sign_sim))$p.value
  #difruns= difference.sign.test(sim_data)$p.value
  tp= turningpoint.test(sim_data)$p.value
  VNR=bartels.rank.test(sim_data)$p.value
  if (center==FALSE){
    vz3=pdepth(calcDepth(sim_data,K=3, transform=T),N=n,K=3, transform=T)
    vz4=pdepth(calcDepth(sim_data,K=4, transform=T),N=n,K=4, transform=T)
    vz5=pdepth(calcDepth(sim_data,K=5, transform=T),N=n,K=5, transform=T)
    vzK=calcDepth(sim_data,K=floor(n/3), transform=T)
  }else{
    vz3=pdepth(calcDepth(res_sim,K=3, transform=T),N=n,K=3, transform=T)
    vz4=pdepth(calcDepth(res_sim,K=4, transform=T),N=n,K=4, transform=T)
    vz5=pdepth(calcDepth(res_sim,K=5, transform=T),N=n,K=5, transform=T)
    vzK=calcDepth(res_sim,K=floor(n/3), transform=T)
  }
  
  ### Simplified K=2
  VZWK2= (1/(n-1))*sum(diff(sign(sim_data)) != 0)
  TestStatK2= sqrt(n-1)* ((VZWK2- (1/2)^(1))/ (sqrt((1/2)^(1) * (3- (1/2)^(0) * (1) - 3* (1/2)^(1)))))
  SimpK2=pnorm(TestStatK2)
  
  
  ### Simplified K=3
  sumK3=vector()
  for(i in 1:(n-2)){
    sumK3=c(sumK3,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)))
  }
  TestK3= (1/(n-2)) * sum(sumK3)
  TestStatK3= sqrt(n-2)* ((TestK3- (1/2)^2)/(sqrt((1/2)^2*(3-(1/2)^1*2-3*(1/2)^2))))
  SimpK3=pnorm(TestStatK3)
  
  
  ### Simplified K=4
  sumK4=vector()
  for(i in 1:(n-3)){
    sumK4=c(sumK4,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0)*as.numeric(sim_data[i+3]*(1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)*as.numeric(sim_data[i+3]*(-1)>0)))
  }
  TestK4= (1/(n-3)) * sum(sumK4)
  TestStatK4= sqrt(n-3)* ((TestK4- (1/2)^3)/(sqrt((1/2)^3*(3-(1/2)^2*3-3*(1/2)^3))))
  SimpK4=pnorm(TestStatK4)
  
  
  ### Simplified K=5
  sumK5=vector()
  for(i in 1:(n-4)){
    sumK5=c(sumK5,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0)*as.numeric(sim_data[i+3]*(1)>0)*as.numeric(sim_data[i+4]*(-1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)*as.numeric(sim_data[i+3]*(-1)>0)*as.numeric(sim_data[i+4]*(1)>0)))
  }
  TestK5= (1/(n-4)) * sum(sumK5)
  TestStatK5= sqrt(n-4)* ((TestK5- (1/2)^4)/(sqrt((1/2)^4*(3-(1/2)^3*4-3*(1/2)^4))))
  SimpK5=pnorm(TestStatK5)
  
  #return
  test_list=list('Durbin-Watson'=as.numeric(dw<0.05),'VonNeumannRang'= as.numeric(VNR<0.05), 'BDS'=as.numeric(bds<0.05), 'Ljung-Box'=as.numeric(lb<0.05), 'Runs'= as.numeric(runs<0.05),'SimpVZTK2'=as.numeric(SimpK2<0.025||SimpK2>0.975), 'SimpVZTK3'=as.numeric(SimpK3<0.025||SimpK3>0.975), 'SimpVZTK4'=as.numeric(SimpK4<0.025||SimpK4>0.975),'SimpVZTK5'=as.numeric(SimpK5<0.025||SimpK5>0.975), 'Turning-Point'=as.numeric(tp<0.05), '3-VZ'= as.numeric(vz3<0.025||vz3>0.975), '4-VZ'= as.numeric(vz4<0.025||vz4>0.975), '5-VZ'= as.numeric(vz5<0.025||vz5>0.975), 'K-VZ'= as.numeric(vzK<QK[1]||vzK>QK[2]))
  return(test_list)
}



# AR1

RejratesSimp <- function(reps, n,center=FALSE, order, testgrid,distr= 'norm',mean=0,loc=0,scale=NULL,df=NULL,shockno=1,shockint=rnorm(1), shocktime=sample(1:n,shockno), kontno=1, kontint=rnorm(1), konttime=sample(1:n,kontno)){
  X=seq(1:length(testgrid))
  Y=seq(1:reps)
  QuantK= quantile(replicate(100000,calcDepth(runif(n, -1,1), K=floor(n/3),transform=T)), probs=c(0.025,0.975))
  Rates=parallelSapply(X, function(X) 
    colSums(t(parallelSapply(Y, function(Y) as.numeric(TestsSimp(order,QK=QuantK,center=center,rho=as.numeric(testgrid[X]),n=n,mean=mean,distr=distr,df=df,scale=scale,shockno=shockno,shockint=shockint, shocktime=shocktime,kontno=kontno, kontint=kontint, konttime=konttime))))/reps))
  testgrid$Rej= Rates
  return(testgrid)
}


# AR2

Rejrates2Simp <- function(reps, n, order, testgrid,center=FALSE,distr= 'norm',loc=0,scale=1,df=NULL,test,shockno=1,shockint=rnorm(1), shocktime=sample(1:n,shockno), kontno=1, kontint=rnorm(1), konttime=sample(1:n,kontno)){
  X=seq(1:dim(testgrid)[1])
  Y=seq(1:reps)
  QuantK= quantile(replicate(100000,calcDepth(runif(n, -1,1), K=floor(n/3),transform=T)), probs=c(0.025,0.975))
  Rates=parallelSapply(X, function(X) 
    sum(parallelSapply(Y, function(Y) as.numeric(TestsSimp(order=order,QK=QuantK,rho=as.numeric(testgrid[X,]),center=center,mean=0,scale=scale,n=n,distr=distr,df=df,shockno=shockno,shockint=shockint, shocktime=shocktime,kontno=kontno, kontint=kontint, konttime=konttime)[test][[1]])))/reps)
  testgrid$Rej= Rates
  return(testgrid)
}







####### Tests Simplified Seasonal

TestsSimpS<- function(order=order,QK=QK,season=season,rho=rho,mean=mean,center=center,n=n,distr=distr,df=df,scale=scale,shockno=shockno,shockint=shockint, shocktime=shocktime, kontno=kontno, kontint=kontint, konttime=konttime){
  
  #Generieren + Residuen +Signs
  if ((distr=='norm')){
    shock=rnorm(n)
  }  else
  {if (!(is.null(df))){
    shock=do.call(paste("r",distr[[1]],sep=""),args=list(n=n, df=df))
  } else
  {if (!(missing(scale))){
    shock=do.call(paste("r",distr[[1]],sep=""),args=list(n=n, scale=scale))}
  }}
  
  shock[shocktime]= sample(c(-1,1),shockno,replace=T)*shockint
  sim_data=arima.sim(list(order=order, ar=c(rep(0,season-1),rho),mean=mean),innov=shock, n=n)
  sim_data[konttime]= sim_data[konttime]+sample(c(-1,1),kontno,replace=T)*kontint
  res_sim = sim_data - median(sim_data)
  sign_sim= sign_w0(res_sim)
  
  #Tests
  dw= dwtest(sim_data~ 1+seq(1,n), alternative= 'two.sided')$p
  bg=bgtest(sim_data~1 + seq(1,n))$p.value
  lb=Box.test(sim_data, lag = 15, type = "Ljung-Box", fitdf = 0)$p.value
  bds=bds.test(sim_data,m=2, eps= 0.5*sd(sim_data))$p.value                 #S. BDS-Statistic 2.
  runs=tseries::runs.test(as.factor(sign_sim))$p.value
  #difruns= difference.sign.test(sim_data)$p.value
  tp= turningpoint.test(sim_data)$p.value
  VNR=bartels.rank.test(sim_data)$p.value
  if (center==FALSE){
    vz3=pdepth(calcDepth(sim_data,K=3, transform=T),N=n,K=3, transform=T)
    vz4=pdepth(calcDepth(sim_data,K=4, transform=T),N=n,K=4, transform=T)
    vz5=pdepth(calcDepth(sim_data,K=5, transform=T),N=n,K=5, transform=T)
    vzK=calcDepth(sim_data,K=floor(n/3), transform=T)
    
  }else{
    vz3=pdepth(calcDepth(res_sim,K=3, transform=T),N=n,K=3, transform=T)
    vz4=pdepth(calcDepth(res_sim,K=4, transform=T),N=n,K=4, transform=T)
    vz5=pdepth(calcDepth(res_sim,K=5, transform=T),N=n,K=5, transform=T)
    vzK=calcDepth(res_sim,K=floor(n/3), transform=T)
    
  }
  
  ### Simplified K=2
  VZWK2= (1/(n-1))*sum(diff(sign(sim_data)) != 0)
  TestStatK2= sqrt(n-1)* ((VZWK2- (1/2)^(1))/ (sqrt((1/2)^(1) * (3- (1/2)^(0) * (1) - 3* (1/2)^(1)))))
  SimpK2=pnorm(TestStatK2)
  
  
  ### Simplified K=3
  sumK3=vector()
  for(i in 1:(n-2)){
    sumK3=c(sumK3,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)))
  }
  TestK3= (1/(n-2)) * sum(sumK3)
  TestStatK3= sqrt(n-2)* ((TestK3- (1/2)^2)/(sqrt((1/2)^2*(3-(1/2)^1*2-3*(1/2)^2))))
  SimpK3=pnorm(TestStatK3)
  
  
  ### Simplified K=4
  sumK4=vector()
  for(i in 1:(n-3)){
    sumK4=c(sumK4,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0)*as.numeric(sim_data[i+3]*(1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)*as.numeric(sim_data[i+3]*(-1)>0)))
  }
  TestK4= (1/(n-3)) * sum(sumK4)
  TestStatK4= sqrt(n-3)* ((TestK4- (1/2)^3)/(sqrt((1/2)^3*(3-(1/2)^2*3-3*(1/2)^3))))
  SimpK4=pnorm(TestStatK4)
  
  
  ### Simplified K=5
  sumK5=vector()
  for(i in 1:(n-4)){
    sumK5=c(sumK5,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0)*as.numeric(sim_data[i+3]*(1)>0)*as.numeric(sim_data[i+4]*(-1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)*as.numeric(sim_data[i+3]*(-1)>0)*as.numeric(sim_data[i+4]*(1)>0)))
  }
  TestK5= (1/(n-4)) * sum(sumK5)
  TestStatK5= sqrt(n-4)* ((TestK5- (1/2)^4)/(sqrt((1/2)^4*(3-(1/2)^3*4-3*(1/2)^4))))
  SimpK5=pnorm(TestStatK5)
  
  #return
  test_list=list('Durbin-Watson'=as.numeric(dw<0.05),'VonNeumannRang'= as.numeric(VNR<0.05), 'BDS'=as.numeric(bds<0.05), 'Ljung-Box'=as.numeric(lb<0.05), 'Runs'= as.numeric(runs<0.05),'SimpVZTK2'=as.numeric(SimpK2<0.025||SimpK2>0.975), 'SimpVZTK3'=as.numeric(SimpK3<0.025||SimpK3>0.975), 'SimpVZTK4'=as.numeric(SimpK4<0.025||SimpK4>0.975),'SimpVZTK5'=as.numeric(SimpK5<0.025||SimpK5>0.975), 'Turning-Point'=as.numeric(tp<0.05), '3-VZ'= as.numeric(vz3<0.025||vz3>0.975), '4-VZ'= as.numeric(vz4<0.025||vz4>0.975), '5-VZ'= as.numeric(vz5<0.025||vz5>0.975), 'K-VZ'= as.numeric(vzK<QK[1]||vzK>QK[2]))
  return(test_list)
}




# Saisonal
RejratesSimpS<- function(reps, n,center=FALSE,test, testgrid,distr= 'norm',mean=0,loc=0,scale=NULL,df=NULL,shockno=1,shockint=rnorm(1), shocktime=sample(1:n,shockno), kontno=1, kontint=rnorm(1), konttime=sample(1:n,kontno)){
  X=seq(1:dim(testgrid)[1])
  Y=seq(1:reps)
  QuantK= quantile(replicate(100000,calcDepth(runif(n, -1,1), K=floor(n/3),transform=T)), probs=c(0.025,0.975))
  
  Rates=parallelSapply(X, function(X) 
    rowSums(parallelSapply(Y, function(Y) as.numeric(TestsSimpS(order=c(as.numeric(testgrid[X,2]),0,0),QK=QuantK,season=as.numeric(testgrid[X,2]),rho=as.numeric(testgrid[X,1]),center=center,n=n,mean=mean,distr=distr,df=df,scale=scale,shockno=shockno,shockint=shockint, shocktime=shocktime,kontno=kontno, kontint=kontint, konttime=konttime)))))
  
  return(Rates)
}




# Drift


TestsD<- function(order,QK=QK,rho,drift=2,n,distr='norm',df=1,scale=1,shockno=shockno,shockint=shockint, shocktime=shocktime, kontno=kontno, kontint=kontint, konttime=konttime){
  
  #Generieren + Residuen +Signs
  if ((distr=='norm')){
    shock=rnorm(n)
  }  else
  {if (!(is.null(df))){
    shock=do.call(paste("r",distr[[1]],sep=""),args=list(n=n, df=df))
  } else
  {if (!(missing(scale))){
    shock=do.call(paste("r",distr[[1]],sep=""),args=list(n=n, scale=scale))}
  }}
  
  shock[shocktime]= shockint
  sim_dataD=arima.sim(list(order=order, ar=rho),innov=shock, n=n)
  sim_dataD[konttime]= kontint
  sim_data= sim_dataD  + drift/n *seq(-n/2,n/2-1)
  
  
  
  res_sim = sim_data - median(sim_data)
  sign_sim= sign_w0(res_sim)
  
  #Tests
  dw= dwtest(sim_data~ 1+seq(1,n), alternative= 'two.sided')$p
  bg=bgtest(sim_data~1 + seq(1,n))$p.value
  lb=Box.test(sim_data, lag = 15, type = "Ljung-Box", fitdf = 0)$p.value
  bds=bds.test(sim_data,m=2, eps= 0.5*sd(sim_data))$p.value                 #S. BDS-Statistic 2.
  runs=tseries::runs.test(as.factor(sign_sim))$p.value
  difruns= difference.sign.test(sim_data)$p.value
  tp= turningpoint.test(sim_data)$p.value
  VNR=bartels.rank.test(sim_data)$p.value
  vz3=pdepth(calcDepth(sim_data,K=3, transform=T),N=n,K=3, transform=T)
  vz4=pdepth(calcDepth(sim_data,K=4, transform=T),N=n,K=4, transform=T)
  vz5=pdepth(calcDepth(sim_data,K=5, transform=T),N=n,K=5, transform=T)
  vzK=calcDepth(sim_data,K=floor(n/3), transform=T)
  
  
  
  ### Simplified K=2
  VZWK2= (1/(n-1))*sum(diff(sign(sim_data)) != 0)
  TestStatK2= sqrt(n-1)* ((VZWK2- (1/2)^(1))/ (sqrt((1/2)^(1) * (3- (1/2)^(0) * (1) - 3* (1/2)^(1)))))
  SimpK2=pnorm(TestStatK2)
  
  
  ### Simplified K=3
  sumK3=vector()
  for(i in 1:(n-2)){
    sumK3=c(sumK3,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)))
  }
  TestK3= (1/(n-2)) * sum(sumK3)
  TestStatK3= sqrt(n-2)* ((TestK3- (1/2)^2)/(sqrt((1/2)^2*(3-(1/2)^1*2-3*(1/2)^2))))
  SimpK3=pnorm(TestStatK3)
  
  
  ### Simplified K=4
  sumK4=vector()
  for(i in 1:(n-3)){
    sumK4=c(sumK4,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0)*as.numeric(sim_data[i+3]*(1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)*as.numeric(sim_data[i+3]*(-1)>0)))
  }
  TestK4= (1/(n-3)) * sum(sumK4)
  TestStatK4= sqrt(n-3)* ((TestK4- (1/2)^3)/(sqrt((1/2)^3*(3-(1/2)^2*3-3*(1/2)^3))))
  SimpK4=pnorm(TestStatK4)
  
  
  ### Simplified K=5
  sumK5=vector()
  for(i in 1:(n-4)){
    sumK5=c(sumK5,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0)*as.numeric(sim_data[i+3]*(1)>0)*as.numeric(sim_data[i+4]*(-1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)*as.numeric(sim_data[i+3]*(-1)>0)*as.numeric(sim_data[i+4]*(1)>0)))
  }
  TestK5= (1/(n-4)) * sum(sumK5)
  TestStatK5= sqrt(n-4)* ((TestK5- (1/2)^4)/(sqrt((1/2)^4*(3-(1/2)^3*4-3*(1/2)^4))))
  SimpK5=pnorm(TestStatK5)
  
  #return
  test_list=list('Durbin-Watson'=as.numeric(dw<0.05),'VonNeumannRang'= as.numeric(VNR<0.05), 'BDS'=as.numeric(bds<0.05), 'Ljung-Box'=as.numeric(lb<0.05), 'Runs'= as.numeric(runs<0.05),'SimpVZTK2'=as.numeric(SimpK2<0.025||SimpK2>0.975), 'SimpVZTK3'=as.numeric(SimpK3<0.025||SimpK3>0.975), 'SimpVZTK4'=as.numeric(SimpK4<0.025||SimpK4>0.975),'SimpVZTK5'=as.numeric(SimpK5<0.025||SimpK5>0.975), 'Turning-Point'=as.numeric(tp<0.05), '3-VZ'= as.numeric(vz3<0.025||vz3>0.975), '4-VZ'= as.numeric(vz4<0.025||vz4>0.975), '5-VZ'= as.numeric(vz5<0.025||vz5>0.975), 'K-VZ'= as.numeric(vzK<QK[1]||vzK>QK[2]))
  return(test_list)
}



RejratesD2 <- function(reps, n, order, testgrid,distr= 'norm',loc=0,scale=1,df=NULL,test,shockno=1,shockint=rnorm(1), shocktime=sample(1:n,shockno), kontno=1, kontint=rnorm(1), konttime=sample(1:n,kontno)){
  X=seq(1:dim(testgrid)[1])
  Y=seq(1:reps)
  QuantK= quantile(replicate(100000,calcDepth(runif(n, -1,1), K=floor(n/3),transform=T)), probs=c(0.025,0.975))
  
  Rates=parallelSapply(X, function(X) 
    rowSums(parallelSapply(Y, function(Y) as.numeric(TestsD(order,QK=QuantK,rho=as.numeric(testgrid[X,1]),drift=as.numeric(testgrid[X,2]),n,distr=distr,df=df,shockno=shockno,shockint=shockint, shocktime=shocktime,kontno=konto, kontint=kontint, konttime=konttime)[test])))/reps)
  
  for(j in 1:length(test)){
    testgrid[[paste('Rej',test[j],sep="")]]= Rates[j,]}
  return(testgrid)
}






TestsSprung2<- function(order=order,rho=rho,QK=QK,mean=mean,n=n,hhe=hhe,distr=distr,df=df,scale=scale,shockno=shockno,shockint=shockint, shocktime=shocktime, kontno=kontno, kontint=kontint, konttime=konttime){
  
  #Generieren + Residuen +Signs
  if ((distr=='norm')){
    shock=rnorm(n)
  }  else
  {if (!(is.null(df))){
    shock=do.call(paste("r",distr[[1]],sep=""),args=list(n=n, df=df))
  } else
  {if (!(missing(scale))){
    shock=do.call(paste("r",distr[[1]],sep=""),args=list(n=n, scale=scale))}
  }}
  shock[shocktime]= shockint
  sim_data=arima.sim(list(order=order, ar=rho,mean=mean),innov=shock, n=n)
  sim_data[floor(length(sim_data)/2):length(sim_data)]=sim_data[floor(length(sim_data)/2):length(sim_data)]+hhe/2
  sim_data[1:floor(length(sim_data)/2)-1]=sim_data[1:floor(length(sim_data)/2)-1]-hhe/2
  sim_data[konttime]= kontint
  res_sim = sim_data - median(sim_data)
  sign_sim= sign_w0(res_sim)
  
  #Tests
  dw= dwtest(sim_data~ 1+seq(1,n), alternative= 'two.sided')$p
  bg=bgtest(sim_data~1 + seq(1,n))$p.value
  lb=Box.test(sim_data, lag = 15, type = "Ljung-Box", fitdf = 0)$p.value
  bds=bds.test(sim_data,m=2, eps= 0.5*sd(sim_data))$p.value                 #S. BDS-Statistic 2.
  runs=tseries::runs.test(as.factor(sign_sim))$p.value
  difruns= difference.sign.test(sim_data)$p.value
  tp= turningpoint.test(sim_data)$p.value
  VNR=bartels.rank.test(sim_data)$p.value
  vz3=pdepth(calcDepth(res_sim,K=3, transform=T),N=n,K=3, transform=T)
  vz4=pdepth(calcDepth(res_sim,K=4, transform=T),N=n,K=4, transform=T)
  vz5=pdepth(calcDepth(res_sim,K=5, transform=T),N=n,K=5, transform=T)
  vzK=calcDepth(res_sim,K=floor(n/3), transform=T)
  
  ### Simplified K=2
  VZWK2= (1/(n-1))*sum(diff(sign(sim_data)) != 0)
  TestStatK2= sqrt(n-1)* ((VZWK2- (1/2)^(1))/ (sqrt((1/2)^(1) * (3- (1/2)^(0) * (1) - 3* (1/2)^(1)))))
  SimpK2=pnorm(TestStatK2)
  
  
  ### Simplified K=3
  sumK3=vector()
  for(i in 1:(n-2)){
    sumK3=c(sumK3,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)))
  }
  TestK3= (1/(n-2)) * sum(sumK3)
  TestStatK3= sqrt(n-2)* ((TestK3- (1/2)^2)/(sqrt((1/2)^2*(3-(1/2)^1*2-3*(1/2)^2))))
  SimpK3=pnorm(TestStatK3)
  
  
  ### Simplified K=4
  sumK4=vector()
  for(i in 1:(n-3)){
    sumK4=c(sumK4,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0)*as.numeric(sim_data[i+3]*(1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)*as.numeric(sim_data[i+3]*(-1)>0)))
  }
  TestK4= (1/(n-3)) * sum(sumK4)
  TestStatK4= sqrt(n-3)* ((TestK4- (1/2)^3)/(sqrt((1/2)^3*(3-(1/2)^2*3-3*(1/2)^3))))
  SimpK4=pnorm(TestStatK4)
  
  
  ### Simplified K=5
  sumK5=vector()
  for(i in 1:(n-4)){
    sumK5=c(sumK5,(as.numeric(sim_data[i]*(-1)>0)*as.numeric(sim_data[i+1]*(1)>0)*as.numeric(sim_data[i+2]*(-1)>0)*as.numeric(sim_data[i+3]*(1)>0)*as.numeric(sim_data[i+4]*(-1)>0) + as.numeric(sim_data[i]*(1)>0)*as.numeric(sim_data[i+1]*(-1)>0)*as.numeric(sim_data[i+2]*(1)>0)*as.numeric(sim_data[i+3]*(-1)>0)*as.numeric(sim_data[i+4]*(1)>0)))
  }
  TestK5= (1/(n-4)) * sum(sumK5)
  TestStatK5= sqrt(n-4)* ((TestK5- (1/2)^4)/(sqrt((1/2)^4*(3-(1/2)^3*4-3*(1/2)^4))))
  SimpK5=pnorm(TestStatK5)
  
  #return
  test_list=list('Durbin-Watson'=as.numeric(dw<0.05),'VonNeumannRang'= as.numeric(VNR<0.05), 'BDS'=as.numeric(bds<0.05), 'Ljung-Box'=as.numeric(lb<0.05), 'Runs'= as.numeric(runs<0.05),'SimpVZTK2'=as.numeric(SimpK2<0.025||SimpK2>0.975), 'SimpVZTK3'=as.numeric(SimpK3<0.025||SimpK3>0.975), 'SimpVZTK4'=as.numeric(SimpK4<0.025||SimpK4>0.975),'SimpVZTK5'=as.numeric(SimpK5<0.025||SimpK5>0.975), 'Turning-Point'=as.numeric(tp<0.05), '3-VZ'= as.numeric(vz3<0.025||vz3>0.975), '4-VZ'= as.numeric(vz4<0.025||vz4>0.975), '5-VZ'= as.numeric(vz5<0.025||vz5>0.975), 'K-VZ'= as.numeric(vzK<QK[1]||vzK>QK[2]))
  return(test_list)
}





RejratesSprung2 <- function(reps, n, order, testgrid,distr= 'norm',loc=0,scale=1,df=NULL,test,shockno=1,shockint=rnorm(1), shocktime=sample(1:n,shockno), kontno=1, kontint=rnorm(1),mean=0, konttime=sample(1:n,kontno)){
  X=seq(1:dim(testgrid)[1])
  Y=seq(1:reps)
  QuantK= quantile(replicate(100000,calcDepth(runif(n, -1,1), K=floor(n/3),transform=T)), probs=c(0.025,0.975))
  
  Rates=parallelSapply(X, function(X) 
    rowSums(parallelSapply(Y, function(Y) as.numeric(TestsSprung2(order,QK=QuantK,rho=as.numeric(testgrid[X,1]),hhe=as.numeric(testgrid[X,2]),n=n,distr=distr,df=df,shockno=shockno,shockint=shockint, shocktime=shocktime,kontno=konto, kontint=kontint, konttime=konttime,mean=mean)[test])))/reps)
  
  for(j in 1:length(test)){
    testgrid[[paste('Rej',test[j],sep="")]]= Rates[j,]}
  return(testgrid)
}





#################### Simulations and figures: ################


########## AR(1) normal ############


## N=50

AR1_50_Simp=RejratesSimp(reps=100, n=50,order=c(1,0,0),testgrid= Grid_AR1_Simple)

##


Gem_AR1_50_Simp_K2 = AR1_50_Simp$Rej[c(seq(1,4),10,5,seq(6,9),seq(11,14)),]

rownames(Gem_AR1_50_Simp_K2)<-c('Durbin-Watson','Von-Neumann', 'BDS', 'Ljung-Box', 'Turning-Point', 'Runs','Simp. 2-Depth', 'Simp. 3-Depth', 'Simp. 4-Depth','Simp. 5-Depth', '3-Depth', '4-Depth', '5-Depth','(T/3)-Depth')

colnames(Gem_AR1_50_Simp_K2) <- c(seq(-0.99,0.99,by=0.01))


AR1_50_Simp_K2_Levelplot=levelplot(t(Gem_AR1_50_Simp_K2),colorkey=list(labels=list(font=2)),ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.7),scales=list(x=list(font=2,at=seq(10,length(Grid_AR1_Simple),by=10),labels=(seq(-0.9,0.9,by=0.1)),cex=1),y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))

windows(width=10,height=7)                                                                                  
plot(AR1_50_Simp_K2_Levelplot)
update(AR1_50_Simp_K2_Levelplot, aspect=0.5)



## N=500

AR1_500_Simp=RejratesSimp(reps=100, n=500,order=c(1,0,0),testgrid= Grid_AR1_Simple)

##


Gem_AR1_500_Simp_K2 = AR1_500_Simp$Rej[c(seq(1,4),10,5,seq(6,9),seq(11,14)),]

rownames(Gem_AR1_500_Simp_K2)<-c('Durbin-Watson','Von-Neumann', 'BDS', 'Ljung-Box', 'Turning-Point', 'Runs','Simp. 2-Depth', 'Simp. 3-Depth', 'Simp. 4-Depth','Simp. 5-Depth', '3-Depth', '4-Depth', '5-Depth','(T/3)-Depth')

colnames(Gem_AR1_500_Simp_K2) <- c(seq(-0.99,0.99,by=0.01))


AR1_500_Simp_K2_Levelplot=levelplot(t(Gem_AR1_500_Simp_K2),colorkey=list(labels=list(font=2)),ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.7),scales=list(x=list(font=2,at=seq(10,length(Grid_AR1_Simple),by=10),labels=(seq(-0.9,0.9,by=0.1)),cex=1),y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))

windows(width=10,height=7)                                                                                  
plot(AR1_500_Simp_K2_Levelplot)
update(AR1_500_Simp_K2_Levelplot, aspect=0.5)





######### AR(1) innovativ outliers ##############



### n=50

AR1_50_Simp_IA=RejratesSimp(reps=100, n=50,order=c(1,0,0),testgrid= Grid_AR1_Simple,shockno=3, shockint=50)

Gem_AR1_50_Simp_IA = AR1_50_Simp_IA$Rej[c(seq(1,4),10,5,seq(6,9),seq(11,14)),]
rownames(Gem_AR1_50_Simp_IA)<- c('Durbin-Watson','Von-Neumann', 'BDS', 'Ljung-Box', 'Turning-Point', 'Runs','Simp. 2-Depth', 'Simp. 3-Depth', 'Simp. 4-Depth','Simp. 5-Depth', '3-Depth', '4-Depth', '5-Depth','(T/3)-Depth')
colnames(Gem_AR1_50_Simp_IA) <- c(seq(-0.99,0.99,by=0.01)[-100])


AR1_50_Simp_IA_Levelplot=levelplot(t(Gem_AR1_50_Simp_IA),colorkey=list(labels=list(font=2)),ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.7),scales=list(x=list(font=2,at=seq(10,length(Grid_AR1_Simple),by=10),labels=(seq(-0.9,0.9,by=0.1)),cex=1),y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))

windows(width=10,height=7)                                                                                  
plot(AR1_50_Simp_IA_Levelplot)
update(AR1_50_Simp_IA_Levelplot, aspect=0.5)


### n=500

AR1_500_Simp_IA=RejratesSimp(reps=100, n=500,order=c(1,0,0),testgrid= Grid_AR1_Simple,shockno=25, shockint=50)

Gem_AR1_500_Simp_IA = AR1_500_Simp_IA$Rej[c(seq(1,4),10,5,seq(6,9),seq(11,14)),]
rownames(Gem_AR1_500_Simp_IA)<- c('Durbin-Watson','Von-Neumann', 'BDS', 'Ljung-Box', 'Turning-Point', 'Runs','Simp. 2-Depth', 'Simp. 3-Depth', 'Simp. 4-Depth','Simp. 5-Depth', '3-Depth', '4-Depth', '5-Depth','(T/3)-Depth')
colnames(Gem_AR1_500_Simp_IA) <- c(seq(-0.99,0.99,by=0.01)[-100])


AR1_500_Simp_IA_Levelplot=levelplot(t(Gem_AR1_500_Simp_IA),colorkey=list(labels=list(font=2)),ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.7),scales=list(x=list(font=2,at=seq(10,length(Grid_AR1_Simple),by=10),labels=(seq(-0.9,0.9,by=0.1)),cex=1),y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))

windows(width=10,height=7)                                                                                  
plot(AR1_500_Simp_IA_Levelplot)
update(AR1_500_Simp_IA_Levelplot, aspect=0.5)





######## AR(1) additive outliers ############



### n=50

AR1_50_Simp_AA=RejratesSimp(reps=100, n=50,order=c(1,0,0),testgrid= Grid_AR1_Simple,kontno=3, kontint=50)

Gem_AR1_50_Simp_AA = AR1_50_Simp_AA$Rej[c(seq(1,4),10,5,seq(6,9),seq(11,14)),]
rownames(Gem_AR1_50_Simp_AA)<- c('Durbin-Watson','Von-Neumann', 'BDS', 'Ljung-Box', 'Turning-Point', 'Runs','Simp. 2-Depth', 'Simp. 3-Depth', 'Simp. 4-Depth','Simp. 5-Depth', '3-Depth', '4-Depth', '5-Depth','(T/3)-Depth')
colnames(Gem_AR1_50_Simp_AA) <- c(seq(-0.99,0.99,by=0.01)[-100])


AR1_50_Simp_AA_Levelplot=levelplot(t(Gem_AR1_50_Simp_AA),colorkey=list(labels=list(font=2)),ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.7),scales=list(x=list(font=2,at=seq(10,length(Grid_AR1_Simple),by=10),labels=(seq(-0.9,0.9,by=0.1)),cex=1),y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))

windows(width=10,height=7)                                                                                  
plot(AR1_50_Simp_AA_Levelplot)
update(AR1_50_Simp_AA_Levelplot, aspect=0.5)




### n=500

AR1_500_Simp_AA=RejratesSimp(reps=100, n=500,order=c(1,0,0),testgrid= Grid_AR1_Simple,kontno=25, kontint=50)

Gem_AR1_500_Simp_AA = AR1_500_Simp_AA$Rej[c(seq(1,4),10,5,seq(6,9),seq(11,14)),]
rownames(Gem_AR1_500_Simp_AA)<- c('Durbin-Watson','Von-Neumann', 'BDS', 'Ljung-Box', 'Turning-Point', 'Runs','Simp. 2-Depth', 'Simp. 3-Depth', 'Simp. 4-Depth','Simp. 5-Depth', '3-Depth', '4-Depth', '5-Depth','(T/3)-Depth')
colnames(Gem_AR1_500_Simp_AA) <- c(seq(-0.99,0.99,by=0.01)[-100])


AR1_500_Simp_AA_Levelplot=levelplot(t(Gem_AR1_500_Simp_AA),colorkey=list(labels=list(font=2)),ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.7),scales=list(x=list(font=2,at=seq(10,length(Grid_AR1_Simple),by=10),labels=(seq(-0.9,0.9,by=0.1)),cex=1),y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))

windows(width=10,height=7)                                                                                  
plot(AR1_500_Simp_AA_Levelplot)
update(AR1_500_Simp_AA_Levelplot, aspect=0.5)





############ AR(2) normal ################

CJAR2= CJ(rho1=c(-1.99,seq(-1.9,1.9,by=0.1),1.99),rho2= c(-0.99,seq(-0.9,0.9,by=0.1),0.99))

Grid_AR2 <- as.data.frame(CJAR2[(rho2>-1) & (rho2-rho1<0.99) & (rho2 + rho1<0.99) | (rho2>-1) & (rho1- rho2>-0.99)& (rho1+rho2<0.99)])



###n=500

AR2_Simp_500_DW=Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='Durbin-Watson')

AR2_Simp_500_V2VZ=Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='SimpVZTK2')

AR2_Simp_500_V3VZ=Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='SimpVZTK3')

AR2_Simp_500_V4VZ=Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='SimpVZTK4')

AR2_Simp_500_V5VZ=Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='SimpVZTK5')

AR2_Simp_500_Sign= Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='Runs')

AR2_Simp_500_TP= Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='Turning-Point')

AR2_Simp_500_LB= Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='Ljung-Box')

AR2_Simp_500_BDS= Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='BDS')

AR2_Simp_500_3VZ= Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='3-VZ')

AR2_Simp_500_5VZ= Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='5-VZ')

AR2_Simp_500_VNR= Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='VonNeumannRang')

AR2_Simp_500_KVZ=Rejrates2Simp(reps=100, n=500,order=c(2,0,0),testgrid= Grid_AR2, test='K-VZ')




L_AR2_Simp_500_DW=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_DW  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                            main="Durbin-Watson",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_Simp_500_LB=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_LB  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                            main="Ljung-Box",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_Simp_500_Sign=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_Sign  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                              main="Runs",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_Simp_500_TP=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_TP  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                            main="Turning-Point",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_Simp_500_VNR=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_VNR  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                             main="Von-Neumann",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_Simp_500_V2VZ=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_V2VZ  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                              main="Simp. 2-VZ",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_Simp_500_V3VZ=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_V3VZ  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                              main="Simp. 3-Depth",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_Simp_500_V4VZ=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_V4VZ  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                              main="Simp. 4-Depth",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_Simp_500_V5VZ=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_V5VZ  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                              main="Simp. 5-Depth",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_Simp_500_KVZ=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_KVZ  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                             main="(T/3)-Depth",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_500_BDS=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_BDS  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                        main="BDS",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_500_3VZ=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_3VZ  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                        main="3-Depth",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)

L_AR2_500_5VZ=levelplot(Rej ~ rho1*rho2, data=AR2_Simp_500_5VZ  ,pretty=T,layers=1,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3), ylab=list(label=TeX('$\\rho_{2}$'),cex=1.3),
                        main="5-Depth",col.regions=magma,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1)),  at=seq(0,1,by=0.05),colorkey=FALSE)


windows(width=12, height=10)
grid.arrange(L_AR2_Simp_500_DW,L_AR2_Simp_500_LB,L_AR2_Simp_500_VNR,L_AR2_500_BDS,L_AR2_Simp_500_TP,L_AR2_500_3VZ,L_AR2_500_5VZ,L_AR2_Simp_500_KVZ,L_AR2_Simp_500_Sign,L_AR2_Simp_500_V3VZ,L_AR2_Simp_500_V4VZ,L_AR2_Simp_500_V5VZ,ncol=4)





####### Sarima ##########

AR1_500_Simp_VVZT3=RejratesSimpS(reps=100, n=500,testgrid= Grid_Sarima)



###n=500

### Season1

Season1=(AR1_500_Simp_VVZT3[,(seq(1,dim(AR1_500_Simp_VVZT3)[2],by=6))]/100)[c(1,2,3,4,5,10,6,7,8,9,11,12,13,14),]
colnames(Season1) <- c(seq(-0.99,0.99,by=0.01))
rownames(Season1) <- c('Durbin-Watson','VonNeumannRang','BDS','Ljung-Box', 'Runs', 'Turning-Point','SimpVZTK2', 'SimpVZTK3', 'SimpVZTK4','SimpVZTK5','3-Depth','4-Depth','5-Depth','(T/3)-Depth')

L_Season1= levelplot(t(Season1),colorkey=TRUE,ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))
plot(L_Season1)
update(L_Season1,aspect=0.5)



### Season2
Season2=(AR1_500_Simp_VVZT3[,seq(2,dim(AR1_500_Simp_VVZT3)[2],by=6)]/100)[c(1,2,3,4,5,10,6,7,8,9,11,12,13,14),]
colnames(Season2) <- c(seq(-0.99,0.99,by=0.01))
rownames(Season2) <- c('Durbin-Watson','VonNeumannRang','BDS','Ljung-Box', 'Runs', 'Turning-Point','SimpVZTK2', 'SimpVZTK3', 'SimpVZTK4','SimpVZTK5','3-Depth','4-Depth','5-Depth','(T/3)-Depth')
L_Season2= levelplot(t(Season2),colorkey=FALSE,ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(x=list(font=2,at=seq(10,length(Grid_AR1_Simple),by=10),labels=(seq(-0.9,0.9,by=0.1)),cex=1),y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))
plot(L_Season2)
update(L_Season2,aspect=0.5)




### Season3
Season3=(AR1_500_Simp_VVZT3[,seq(3,dim(AR1_500_Simp_VVZT3)[2],by=6)]/100)[c(1,2,3,4,5,10,6,7,8,9,11,12,13,14),]
colnames(Season3) <- c(seq(-0.99,0.99,by=0.01))
rownames(Season3) <- c('Durbin-Watson','VonNeumannRang','BDS','Ljung-Box', 'Runs', 'Turning-Point','SimpVZTK2', 'SimpVZTK3', 'SimpVZTK4','SimpVZTK5','3-Depth','4-Depth','5-Depth','(T/3)-Depth')

L_Season3= levelplot(t(Season3),colorkey=FALSE,ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(x=list(font=2,at=seq(10,length(Grid_AR1_Simple),by=10),labels=(seq(-0.9,0.9,by=0.1)),cex=1),y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))
plot(L_Season3)
update(L_Season3,aspect=0.5)




### Season4
Season4=(AR1_500_Simp_VVZT3[,seq(4,dim(AR1_500_Simp_VVZT3)[2],by=6)]/100)[c(1,2,3,4,5,10,6,7,8,9,11,12,13,14),]
colnames(Season4) <- c(seq(-0.99,0.99,by=0.01))
rownames(Season4) <- c('Durbin-Watson','VonNeumannRang','BDS','Ljung-Box', 'Runs', 'Turning-Point','SimpVZTK2', 'SimpVZTK3', 'SimpVZTK4','SimpVZTK5','3-Depth','4-Depth','5-Depth','(T/3)-Depth')

L_Season4= levelplot(t(Season4),colorkey=FALSE,ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(x=list(font=2,at=seq(10,length(Grid_AR1_Simple),by=10),labels=(seq(-0.9,0.9,by=0.1)),cex=1),y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))
plot(L_Season4)
update(L_Season4,aspect=0.5)



### Season5
Season5=(AR1_500_Simp_VVZT3[,seq(5,dim(AR1_500_Simp_VVZT3)[2],by=6)]/100)[c(1,2,3,4,5,10,6,7,8,9,11,12,13,14),]
colnames(Season5) <- c(seq(-0.99,0.99,by=0.01))
rownames(Season5) <- c('Durbin-Watson','VonNeumannRang','BDS','Ljung-Box', 'Runs', 'Turning-Point','SimpVZTK2', 'SimpVZTK3', 'SimpVZTK4','SimpVZTK5','3-Depth','4-Depth','5-Depth','(T/3)-Depth')

L_Season5= levelplot(t(Season5),colorkey=FALSE,ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(x=list(font=2,at=seq(10,length(Grid_AR1_Simple),by=10),labels=(seq(-0.9,0.9,by=0.1)),cex=1),y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))
plot(L_Season5)
update(L_Season5,aspect=0.5)


### Season6
Season6=(AR1_500_Simp_VVZT3[,seq(6,dim(AR1_500_Simp_VVZT3)[2],by=6)]/100)[c(1,2,3,4,5,10,6,7,8,9,11,12,13,14),]
colnames(Season6) <- c(seq(-0.99,0.99,by=0.01))
rownames(Season6) <- c('Durbin-Watson','VonNeumannRang','BDS','Ljung-Box', 'Runs', 'Turning-Point','SimpVZTK2', 'SimpVZTK3', 'SimpVZTK4','SimpVZTK5','3-Depth','4-Depth','5-Depth','(T/3)-Depth')

L_Season6= levelplot(t(Season6),colorkey=FALSE,ylab=NULL,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(x=list(font=2,at=seq(10,length(Grid_AR1_Simple),by=10),labels=(seq(-0.9,0.9,by=0.1)),cex=1),y=list(font=2,cex=1)) , at=seq(0,1,by=0.05))
plot(L_Season6)
update(L_Season6,aspect=0.5)


#### Einzelne Tests

###DW
Sarima_Simp_500_DW=list()
Sarima_Simp_500_DW$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_DW$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_DW$Rej=c(Season1[1,],Season2[1,],Season3[1,],Season4[1,],Season5[1,],Season6[1,]) 

L_Sarima_Simp_500_DW= levelplot(Rej~rho*season,data=Sarima_Simp_500_DW,colorkey=FALSE,main="Durbin-Watson", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


######VNR
Sarima_Simp_500_VNR=list()
Sarima_Simp_500_VNR$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_VNR$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_VNR$Rej=c(Season1[2,],Season2[2,],Season3[2,],Season4[2,],Season5[2,],Season6[2,]) 

L_Sarima_Simp_500_VNR= levelplot(Rej~rho*season,data=Sarima_Simp_500_VNR,colorkey=FALSE,main="Von-Neumann", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


######BDS
Sarima_Simp_500_BDS=list()
Sarima_Simp_500_BDS$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_BDS$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_BDS$Rej=c(Season1[3,],Season2[3,],Season3[3,],Season4[3,],Season5[3,],Season6[3,]) 

L_Sarima_Simp_500_BDS= levelplot(Rej~rho*season,data=Sarima_Simp_500_BDS,colorkey=FALSE,main="BDS", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


###LB
Sarima_Simp_500_LB=list()
Sarima_Simp_500_LB$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_LB$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_LB$Rej=c(Season1[4,],Season2[4,],Season3[4,],Season4[4,],Season5[4,],Season6[4,]) 

L_Sarima_Simp_500_LB= levelplot(Rej~rho*season,data=Sarima_Simp_500_LB,colorkey=FALSE,main="Ljung-Box", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


###Runs
Sarima_Simp_500_Runs=list()
Sarima_Simp_500_Runs$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_Runs$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_Runs$Rej=c(Season1[5,],Season2[5,],Season3[5,],Season4[5,],Season5[5,],Season6[5,]) 

L_Sarima_Simp_500_Runs= levelplot(Rej~rho*season,data=Sarima_Simp_500_Runs,colorkey=FALSE,main="Runs", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


###TP
Sarima_Simp_500_TP=list()
Sarima_Simp_500_TP$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_TP$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_TP$Rej=c(Season1[6,],Season2[6,],Season3[6,],Season4[6,],Season5[6,],Season6[6,]) 

L_Sarima_Simp_500_TP= levelplot(Rej~rho*season,data=Sarima_Simp_500_TP,colorkey=FALSE,main="Turning-Point", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


###2VZ
Sarima_Simp_500_2VZ=list()
Sarima_Simp_500_2VZ$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_2VZ$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_2VZ$Rej=c(Season1[7,],Season2[7,],Season3[7,],Season4[7,],Season5[7,],Season6[7,]) 

L_Sarima_Simp_500_2VZ= levelplot(Rej~rho*season,data=Sarima_Simp_500_2VZ,colorkey=FALSE,main="Simp. 2-Depth", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


###3VZ
Sarima_Simp_500_3VZ=list()
Sarima_Simp_500_3VZ$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_3VZ$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_3VZ$Rej=c(Season1[8,],Season2[8,],Season3[8,],Season4[8,],Season5[8,],Season6[8,]) 

L_Sarima_Simp_500_3VZ= levelplot(Rej~rho*season,data=Sarima_Simp_500_3VZ,colorkey=FALSE,main="Simp. 3-Depth", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


###4VZ
Sarima_Simp_500_4VZ=list()
Sarima_Simp_500_4VZ$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_4VZ$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_4VZ$Rej=c(Season1[9,],Season2[9,],Season3[9,],Season4[9,],Season5[9,],Season6[9,]) 

L_Sarima_Simp_500_4VZ= levelplot(Rej~rho*season,data=Sarima_Simp_500_4VZ,colorkey=FALSE,main="Simp. 4-Depth", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


###5VZ
Sarima_Simp_500_5VZ=list()
Sarima_Simp_500_5VZ$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_5VZ$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_5VZ$Rej=c(Season1[10,],Season2[10,],Season3[10,],Season4[10,],Season5[10,],Season6[10,]) 

L_Sarima_Simp_500_5VZ= levelplot(Rej~rho*season,data=Sarima_Simp_500_5VZ,colorkey=FALSE,main="Simp. 5-Depth", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))



###3VZV
Sarima_Simp_500_3VZV=list()
Sarima_Simp_500_3VZV$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_3VZV$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_3VZV$Rej=c(Season1[11,],Season2[11,],Season3[11,],Season4[11,],Season5[11,],Season6[11,]) 

L_Sarima_Simp_500_3VZV= levelplot(Rej~rho*season,data=Sarima_Simp_500_3VZV,colorkey=FALSE,main="3-Depth", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


###4VZV
Sarima_Simp_500_4VZV=list()
Sarima_Simp_500_4VZV$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_4VZV$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_4VZV$Rej=c(Season1[12,],Season2[12,],Season3[12,],Season4[12,],Season5[12,],Season6[12,]) 

L_Sarima_Simp_500_4VZV= levelplot(Rej~rho*season,data=Sarima_Simp_500_4VZV,colorkey=FALSE,main="4-Depth", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


###5VZV
Sarima_Simp_500_5VZV=list()
Sarima_Simp_500_5VZV$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_5VZV$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_5VZV$Rej=c(Season1[13,],Season2[13,],Season3[13,],Season4[13,],Season5[13,],Season6[13,]) 

L_Sarima_Simp_500_5VZV= levelplot(Rej~rho*season,data=Sarima_Simp_500_5VZV,colorkey=FALSE,main="5-Depth", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))


###KVZV
Sarima_Simp_500_KVZV=list()
Sarima_Simp_500_KVZV$season=c(rep(1,199),rep(2,199),rep(3,199),rep(4,199),rep(5,199),rep(6,199))
Sarima_Simp_500_KVZV$rho=rep(seq(-0.99,0.99,by=0.01),6)
Sarima_Simp_500_KVZV$Rej=c(Season1[14,],Season2[14,],Season3[14,],Season4[14,],Season5[14,],Season6[14,]) 

L_Sarima_Simp_500_KVZV= levelplot(Rej~rho*season,data=Sarima_Simp_500_KVZV,colorkey=FALSE,main="(T/3)-Depth", ylab=list(label='season [S]',cex=1.3),pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{S}$'),cex=1.7),scales=list(y=list(font=2,cex=1),x=list(font=2,cex=1)), at=seq(0,1,by=0.05))





windows(width=12,height=10)
grid.arrange(L_Sarima_Simp_500_DW,L_Sarima_Simp_500_LB,L_Sarima_Simp_500_VNR,L_Sarima_Simp_500_BDS,L_Sarima_Simp_500_TP,L_Sarima_Simp_500_3VZV,L_Sarima_Simp_500_5VZV,L_Sarima_Simp_500_KVZV,L_Sarima_Simp_500_Runs,L_Sarima_Simp_500_3VZ,L_Sarima_Simp_500_4VZ,L_Sarima_Simp_500_5VZ,ncol=4)
      





###### AR(1) with jump ###########


Grid_AR1_Sprung= as.data.frame(CJ(rho1=c(-0.99,seq(from=-0.95,to=0.95,by=0.05),0.99),hhe= seq(-5,5,by=0.1)))


AR1_500_Sprung_V2VZ=RejratesSprung2(reps=100, n=500,order=c(1,0,0),testgrid= Grid_AR1_Sprung, test=c("SimpVZTK2","SimpVZTK3","SimpVZTK4","SimpVZTK5",'Durbin-Watson','VonNeumannRang','BDS','Ljung-Box','Runs', 'Turning-Point','3-VZ','4-VZ','5-VZ', 'K-VZ'))


##




colnames(AR1_500_Sprung_V2VZ)[3] <- "RejSimpVZTK2"

colnames(AR1_500_Sprung_V2VZ)[6] <- "RejSimpVZTK5"

colnames(AR1_500_Sprung_V2VZ)[7] <- "RejDurbinWatson"


colnames(AR1_500_Sprung_V2VZ)[8] <- "RejVonNeumannRang"

colnames(AR1_500_Sprung_V2VZ)[9] <- "RejBDS"

colnames(AR1_500_Sprung_V2VZ)[10] <- "RejLjungBox"

colnames(AR1_500_Sprung_V2VZ)[11] <- "RejRuns"

colnames(AR1_500_Sprung_V2VZ)[12] <- "RejTP"

colnames(AR1_500_Sprung_V2VZ)[13] <- "Rej3VZ"

colnames(AR1_500_Sprung_V2VZ)[14] <- "Rej4VZ"

colnames(AR1_500_Sprung_V2VZ)[15] <- "Rej5VZ"

colnames(AR1_500_Sprung_V2VZ)[16] <- "RejKVZ"





### 2VZT
L_AR1_500_V2VZ_Sprung=levelplot(RejSimpVZTK2 ~ rho1*hhe,main="Simp. 2-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))


### 3VZT
L_AR1_500_V3VZ_Sprung=levelplot(RejSimpVZTK3 ~ rho1*hhe,main="Simp. 3-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))


### 4VZT

L_AR1_500_V4VZ_Sprung=levelplot(RejSimpVZTK4 ~ rho1*hhe,main="Simp. 4-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))


### 5VZT

L_AR1_500_V5VZ_Sprung=levelplot(RejSimpVZTK5 ~ rho1*hhe,main="Simp. 5-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))

### DW

L_AR1_500_DW_Sprung=levelplot(RejDurbinWatson ~ rho1*hhe,main="Durbin-Watson",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))


### LB

L_AR1_500_LB_Sprung=levelplot(RejLjungBox ~ rho1*hhe,main="Ljung-Box",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))



### VNR

L_AR1_500_VNR_Sprung=levelplot(RejVonNeumannRang ~ rho1*hhe,main="Von-Neumann",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))



### BDS

L_AR1_500_BDS_Sprung=levelplot(RejBDS ~ rho1*hhe,main="BDS",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))



### Runs

L_AR1_500_Runs_Sprung=levelplot(RejRuns~ rho1*hhe,main="Runs",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))



### TP

L_AR1_500_TP_Sprung=levelplot(RejTP~ rho1*hhe,main="Turning-Point",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))




### 3VZ

L_AR1_500_3VZ_Sprung=levelplot(Rej3VZ~ rho1*hhe,main="3-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))




### TP

L_AR1_500_4VZ_Sprung=levelplot(Rej4VZ~ rho1*hhe,main="4-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))




### TP

L_AR1_500_5VZ_Sprung=levelplot(Rej5VZ~ rho1*hhe,main="5-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))


### K-VZ

L_AR1_500_KVZ_Sprung=levelplot(RejKVZ~ rho1*hhe,main="(T/3)-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5))),  data=AR1_500_Sprung_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='height h',cex=1.3), at=seq(0,1,by=0.05))




windows(width=12,height=9)
grid.arrange(L_AR1_500_DW_Sprung,L_AR1_500_LB_Sprung,L_AR1_500_VNR_Sprung,L_AR1_500_BDS_Sprung,L_AR1_500_TP_Sprung,L_AR1_500_3VZ_Sprung,L_AR1_500_5VZ_Sprung,L_AR1_500_KVZ_Sprung,L_AR1_500_Runs_Sprung,L_AR1_500_V3VZ_Sprung,L_AR1_500_V4VZ_Sprung,L_AR1_500_V5VZ_Sprung, ncol=4)




##### AR(1) with trend ########



Grid_AR1_Drift=as.data.frame(CJ(rho=c(-0.99,seq(-0.95,0.95,by=0.05),0.99),drift= seq(-5,5,by=0.1)))


### 2VZT
AR1_500_Drift_V2VZ=RejratesD2(reps=100, n=500,order=c(1,0,0),testgrid= Grid_AR1_Drift, test=c("SimpVZTK2","SimpVZTK3","SimpVZTK4","SimpVZTK5"))

AR1_500_Drift_V2VZB=RejratesD2(reps=100, n=500,order=c(1,0,0),testgrid= Grid_AR1_Drift, test=c('Durbin-Watson','VonNeumannRang','BDS','Ljung-Box','Runs', 'Turning-Point','3-VZ','4-VZ','5-VZ', 'K-VZ'))

colnames(AR1_500_Drift_V2VZB)[3] <- "RejDurbinWatson"

colnames(AR1_500_Drift_V2VZB)[6] <- "RejLjungBox"

colnames(AR1_500_Drift_V2VZB)[8] <- "RejTP"

colnames(AR1_500_Drift_V2VZB)[9] <- "Rej3VZ"

colnames(AR1_500_Drift_V2VZB)[10] <- "Rej4VZ"

colnames(AR1_500_Drift_V2VZB)[11] <- "Rej5VZ"

colnames(AR1_500_Drift_V2VZB)[12] <- "RejKVZ"


### 2VZT
L_AR1_500_V2VZ_Drift=levelplot(RejSimpVZTK2 ~ rho*drift,main="Simp. 2-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))


### 3VZT
L_AR1_500_V3VZ_Drift=levelplot(RejSimpVZTK3 ~ rho*drift,main="Simp. 3-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))


### 4VZT

L_AR1_500_V4VZ_Drift=levelplot(RejSimpVZTK4 ~ rho*drift,main="Simp. 4-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))


### 5VZT

L_AR1_500_V5VZ_Drift=levelplot(RejSimpVZTK5 ~ rho*drift,main="Simp. 5-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZ,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))

### DW

L_AR1_500_DW_Drift=levelplot(RejDurbinWatson ~ rho*drift,main="Durbin-Watson",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZB,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))

plot(L_AR1_500_DW_Drift)

### LB

L_AR1_500_LB_Drift=levelplot(RejLjungBox ~ rho*drift,main="Ljung-Box",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZB,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))

plot(L_AR1_500_LB_Drift)


### VNR

L_AR1_500_VNR_Drift=levelplot(RejVonNeumannRang ~ rho*drift,main="Von-Neumann",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZB,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))



### BDS

L_AR1_500_BDS_Drift=levelplot(RejBDS ~ rho*drift,main="BDS",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZB,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))



### Runs

L_AR1_500_Runs_Drift=levelplot(RejRuns~ rho*drift,main="Runs",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZB,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))



### TP

L_AR1_500_TP_Drift=levelplot(RejTP~ rho*drift,main="Turning-Point",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZB,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))




### 3VZ

L_AR1_500_3VZ_Drift=levelplot(Rej3VZ~ rho*drift,main="3-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZB,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))




### TP

L_AR1_500_4VZ_Drift=levelplot(Rej4VZ~ rho*drift,main="4-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZB,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))




### TP

L_AR1_500_5VZ_Drift=levelplot(Rej5VZ~ rho*drift,main="5-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZB,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))


L_AR1_500_KVZ_Drift=levelplot(RejKVZ~ rho*drift,main="(T/3)-Depth",colorkey=FALSE,scales=list(x=list(font=2,cex=1),y=list(font=2,cex=1,at=seq(-5,5,by=5),labels=seq(-5,5,by=5)/500)),  data=AR1_500_Drift_V2VZB,pretty=T,col.regions=magma,xlab=list(label=TeX('$\\rho_{1}$'),cex=1.3),ylab=list(label='drift d',cex=1.3), at=seq(0,1,by=0.05))




windows(width=15,height=10)
grid.arrange(L_AR1_500_DW_Drift,L_AR1_500_LB_Drift,L_AR1_500_VNR_Drift,L_AR1_500_BDS_Drift,L_AR1_500_TP_Drift,L_AR1_500_3VZ_Drift,L_AR1_500_5VZ_Drift,L_AR1_500_KVZ_Drift,L_AR1_500_Runs_Drift,L_AR1_500_V3VZ_Drift,L_AR1_500_V4VZ_Drift,L_AR1_500_V5VZ_Drift, ncol=4)


